@@ -57,6 +57,7 @@ from ... git import track_branches
 from ... git import get_last_tag_by_date
 
 from ... logging import error
+from ... logging import info
 from ... logging import warning
 
 try:
@@ -220,6 +221,14 @@ def process_stack_xml(args, cwd=None):
     return data
 
 
+def is_meta_package(package):
+    metapack = [True for e in package.exports if e.tagname == 'metapackage']
+    if len(metapack) > 0:
+        return True
+    else:
+        return False
+
+
 def process_package_xml(args, directory=None):
     cwd = directory if directory else '.'
     xml_path = os.path.join(cwd, 'package.xml')
@@ -244,7 +253,11 @@ def process_package_xml(args, directory=None):
     data['Homepage'] = homepage
 
     data['Catkin-ChangelogType'] = ''
-    data['Catkin-DebRulesType'] = 'cmake'
+    if is_meta_package(package):
+        info("Metapackage detected: " + package.name)
+        data['Catkin-DebRulesType'] = 'metapackage'
+    else:
+        data['Catkin-DebRulesType'] = 'cmake'
     data['Catkin-DebRulesFile'] = ''
     # data['Catkin-CopyrightType'] = package.copyright
     # data['copyright'] = package.copyright
@@ -321,9 +334,8 @@ def expand(fname, stack_data, dest_dir, filetype=''):
     # insert template type
     if fname == 'rules' and stack_data['Catkin-DebRulesType'] == 'custom':
         path = os.path.join(dest_dir, '..', stack_data['Catkin-DebRulesFile'])
-        f = open(path)
-        file_em = f.read()
-        f.close()
+        with open(path, 'r') as f:
+            file_em = f.read()
     else:
         if filetype != '':
             ifilename = (fname + '.' + filetype + '.em')
@@ -354,7 +366,8 @@ def find_deps(stack_data, apt_installer, rosdistro, debian_distro):
     build_deps = stack_data['BuildDepends']
 
     rosdep_view = rosdep2.catkin_support.get_catkin_view(rosdistro, os_name,
-                                                         debian_distro)
+                                                         debian_distro,
+                                                         update=False)
 
     ubuntu_deps = set()
     for dep in deps:
@@ -427,8 +440,8 @@ def generate_deb(stack_data, repo_path, stamp, rosdistro, debian_distro):
 
 def commit_debian(stack_data, repo_path):
     call(repo_path, ['git', 'add', 'debian'])
-    message = "+ Creating debian mods for distro: %(Distribution)s, " + \
-              "rosdistro: %(ROS_DISTRO)s, upstream version: " + \
+    message = "+ Creating debian mods for distro: %(Distribution)s, " \
+              "rosdistro: %(ROS_DISTRO)s, upstream version: " \
               "%(Version)s" % stack_data
     call(repo_path, ['git', 'commit', '-m', message])
 
@@ -451,6 +464,10 @@ Creates or updates a git-buildpackage repository using a catkin project.\
     parser.add_argument('--distros', nargs='+',
                         help='A list of debian distros.',
                         default=[])
+    parser.add_argument('--do-not-update-rosdep',
+                        help="If specified, rosdep will not be updated before "
+                             "generating the debian stuff",
+                        action='store_false', default=True)
     parser.add_argument('--upstream-tag', '-t',
                         help='tag to create debians from', default=None)
 
@@ -549,8 +566,13 @@ def main(sysargs=None):
     bloom_repo = VcsClient('git', os.getcwd())
     result = 0
     try:
+        # update rosdep is needed
+        if args.do_not_update_rosdep:
+            info("Updating rosdep")
+            rosdep2.catkin_support.update_rosdep()
+        # do it
         result = execute_bloom_generate_debian(args, bloom_repo)
     finally:
         if current_branch:
-            bloom_repo.update(current_branch)
+            execute_command('git checkout ' + current_branch)
     return result
